=== modified file 'lib/lp/code/model/sourcepackagerecipebuild.py'
--- lib/lp/code/model/sourcepackagerecipebuild.py	2011-05-17 14:11:30 +0000
+++ lib/lp/code/model/sourcepackagerecipebuild.py	2011-07-14 04:18:59 +0000
@@ -51,7 +51,10 @@
     PackageBuild,
     PackageBuildDerived,
     )
-from lp.code.errors import BuildAlreadyPending
+from lp.code.errors import (
+    BuildAlreadyPending,
+    BuildNotAllowedForDistro,
+    )
 from lp.code.interfaces.sourcepackagerecipebuild import (
     ISourcePackageRecipeBuild,
     ISourcePackageRecipeBuildJob,
@@ -226,6 +229,9 @@
                     logger.debug(
                         ' - daily build failed for %s: %s',
                         series_name, str(e))
+                except BuildNotAllowedForDistro:
+                    logger.debug(
+                        ' - cannot build against %s.' % series_name)
                 except ProgrammingError:
                     raise
                 except:

=== modified file 'lib/lp/code/model/tests/test_sourcepackagerecipebuild.py'
--- lib/lp/code/model/tests/test_sourcepackagerecipebuild.py	2011-05-20 10:28:53 +0000
+++ lib/lp/code/model/tests/test_sourcepackagerecipebuild.py	2011-07-14 04:18:59 +0000
@@ -45,6 +45,7 @@
     SourcePackageRecipeBuildMailer,
     )
 from lp.code.model.sourcepackagerecipebuild import SourcePackageRecipeBuild
+from lp.registry.interfaces.series import SeriesStatus
 from lp.registry.interfaces.pocket import PackagePublishingPocket
 from lp.services.log.logger import BufferLogger
 from lp.services.mail.sendmail import format_address
@@ -409,6 +410,21 @@
         actual_title = [b.title for b in daily_builds]
         self.assertEquals([build.title], actual_title)
 
+    def test_makeDailyBuilds_with_disallowed_series(self):
+        # If a recipe is set to build into a disallowed series,
+        # makeDailyBuilds won't OOPS.
+        recipe = self.factory.makeSourcePackageRecipe(
+            build_daily=True, is_stale=True)
+        self.factory.makeArchive(owner=recipe.owner)
+        logger = BufferLogger()
+        distroseries = list(recipe.distroseries)[0]
+        removeSecurityProxy(distroseries).status = SeriesStatus.OBSOLETE
+        SourcePackageRecipeBuild.makeDailyBuilds(logger)
+        self.assertEquals([], self.oopses)
+        self.assertIn(
+            "DEBUG  - cannot build against Warty (4.10).",
+            logger.getLogBuffer())
+
     def test_getRecentBuilds(self):
         """Recent builds match the same person, series and receipe.
 

